@@ -9,19 +9,17 @@
 package org.mozilla.javascript;
 
 /**
- * Interface to represent arbitrary action that requires to have Context
- * object associated with the current thread for its execution.
+ * Interface to represent arbitrary action that requires to have Context object associated with the
+ * current thread for its execution.
+ *
  * @param T the type of the return value of action execution
  */
-public interface ContextAction<T>
-{
+public interface ContextAction<T> {
     /**
-     * Execute action using the supplied Context instance.
-     * When Rhino runtime calls the method, <code>cx</code> will be associated
-     * with the current thread as active context.
+     * Execute action using the supplied Context instance. When Rhino runtime calls the method,
+     * <code>cx</code> will be associated with the current thread as active context.
      *
      * @see ContextFactory#call(ContextAction)
      */
     public T run(Context cx);
 }
-
