@@ -7,13 +7,9 @@
 package org.mozilla.javascript;
 
 /**
- * A Symbol is a JavaScript objecy that obeys the special properties of the
- * Symbol prototype. This interface lets us possibly support multiple
- * implementations of Symbol.
+ * A Symbol is a JavaScript objecy that obeys the special properties of the Symbol prototype. This
+ * interface lets us possibly support multiple implementations of Symbol.
  *
  * @since 1.7.8
  */
-
-public interface Symbol
-{
-}
+public interface Symbol {}
