@@ -8,101 +8,89 @@ package org.mozilla.javascript.typedarrays;
 
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.IdFunctionObject;
+import org.mozilla.javascript.ScriptRuntimeES6;
 import org.mozilla.javascript.Scriptable;
 import org.mozilla.javascript.Undefined;
 
 /**
- * An array view that stores 16-bit quantities and implements the JavaScript "Uint16Array" interface.
- * It also implements List&lt;Integer&gt; for direct manipulation in Java.
+ * An array view that stores 16-bit quantities and implements the JavaScript "Uint16Array"
+ * interface. It also implements List&lt;Integer&gt; for direct manipulation in Java.
  */
-
-public class NativeUint16Array
-    extends NativeTypedArrayView<Integer>
-{
+public class NativeUint16Array extends NativeTypedArrayView<Integer> {
     private static final long serialVersionUID = 7700018949434240321L;
 
     private static final String CLASS_NAME = "Uint16Array";
     private static final int BYTES_PER_ELEMENT = 2;
 
-    public NativeUint16Array()
-    {
-    }
+    public NativeUint16Array() {}
 
-    public NativeUint16Array(NativeArrayBuffer ab, int off, int len)
-    {
+    public NativeUint16Array(NativeArrayBuffer ab, int off, int len) {
         super(ab, off, len, len * BYTES_PER_ELEMENT);
     }
 
-    public NativeUint16Array(int len)
-    {
-        this(new NativeArrayBuffer((double)len * BYTES_PER_ELEMENT), 0, len);
+    public NativeUint16Array(int len) {
+        this(new NativeArrayBuffer((double) len * BYTES_PER_ELEMENT), 0, len);
     }
 
     @Override
-    public String getClassName()
-    {
+    public String getClassName() {
         return CLASS_NAME;
     }
 
-    public static void init(Context cx, Scriptable scope, boolean sealed)
-    {
+    public static void init(Context cx, Scriptable scope, boolean sealed) {
         NativeUint16Array a = new NativeUint16Array();
-        a.exportAsJSClass(MAX_PROTOTYPE_ID, scope, sealed);
+        IdFunctionObject constructor = a.exportAsJSClass(MAX_PROTOTYPE_ID, scope, sealed);
+        ScriptRuntimeES6.addSymbolSpecies(cx, scope, constructor);
     }
 
     @Override
-    protected NativeUint16Array construct(NativeArrayBuffer ab, int off, int len)
-    {
+    protected NativeUint16Array construct(NativeArrayBuffer ab, int off, int len) {
         return new NativeUint16Array(ab, off, len);
     }
 
     @Override
-    public int getBytesPerElement()
-    {
+    public int getBytesPerElement() {
         return BYTES_PER_ELEMENT;
     }
 
     @Override
-    protected NativeUint16Array realThis(Scriptable thisObj, IdFunctionObject f)
-    {
+    protected NativeUint16Array realThis(Scriptable thisObj, IdFunctionObject f) {
         return ensureType(thisObj, NativeUint16Array.class, f);
     }
 
     @Override
-    protected Object js_get(int index)
-    {
+    protected Object js_get(int index) {
         if (checkIndex(index)) {
             return Undefined.instance;
         }
-        return ByteIo.readUint16(arrayBuffer.buffer, (index * BYTES_PER_ELEMENT) + offset, useLittleEndian());
+        return ByteIo.readUint16(
+                arrayBuffer.buffer, (index * BYTES_PER_ELEMENT) + offset, useLittleEndian());
     }
 
     @Override
-    protected Object js_set(int index, Object c)
-    {
+    protected Object js_set(int index, Object c) {
         if (checkIndex(index)) {
             return Undefined.instance;
         }
         int val = Conversions.toUint16(c);
-        ByteIo.writeUint16(arrayBuffer.buffer, (index * BYTES_PER_ELEMENT) + offset, val, useLittleEndian());
+        ByteIo.writeUint16(
+                arrayBuffer.buffer, (index * BYTES_PER_ELEMENT) + offset, val, useLittleEndian());
         return null;
     }
 
     @Override
-    public Integer get(int i)
-    {
+    public Integer get(int i) {
         if (checkIndex(i)) {
             throw new IndexOutOfBoundsException();
         }
-        return (Integer)js_get(i);
+        return (Integer) js_get(i);
     }
 
     @Override
-    public Integer set(int i, Integer aByte)
-    {
+    public Integer set(int i, Integer aByte) {
         if (checkIndex(i)) {
             throw new IndexOutOfBoundsException();
         }
-        return (Integer)js_set(i, aByte);
+        return (Integer) js_set(i, aByte);
     }
 }
