@@ -8,6 +8,7 @@ package org.mozilla.javascript.typedarrays;
 
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.IdFunctionObject;
+import org.mozilla.javascript.ScriptRuntimeES6;
 import org.mozilla.javascript.Scriptable;
 import org.mozilla.javascript.Undefined;
 
@@ -15,61 +16,49 @@ import org.mozilla.javascript.Undefined;
  * An array view that stores 8-bit quantities and implements the JavaScript "Uint8Array" interface.
  * It also implements List&lt;Integer&gt; for direct manipulation in Java.
  */
-
-public class NativeUint8Array
-    extends NativeTypedArrayView<Integer>
-{
+public class NativeUint8Array extends NativeTypedArrayView<Integer> {
     private static final long serialVersionUID = -3349419704390398895L;
 
     private static final String CLASS_NAME = "Uint8Array";
 
-    public NativeUint8Array()
-    {
-    }
+    public NativeUint8Array() {}
 
-    public NativeUint8Array(NativeArrayBuffer ab, int off, int len)
-    {
+    public NativeUint8Array(NativeArrayBuffer ab, int off, int len) {
         super(ab, off, len, len);
     }
 
-    public NativeUint8Array(int len)
-    {
+    public NativeUint8Array(int len) {
         this(new NativeArrayBuffer(len), 0, len);
     }
 
     @Override
-    public String getClassName()
-    {
+    public String getClassName() {
         return CLASS_NAME;
     }
 
-    public static void init(Context cx, Scriptable scope, boolean sealed)
-    {
+    public static void init(Context cx, Scriptable scope, boolean sealed) {
         NativeUint8Array a = new NativeUint8Array();
-        a.exportAsJSClass(MAX_PROTOTYPE_ID, scope, sealed);
+        IdFunctionObject constructor = a.exportAsJSClass(MAX_PROTOTYPE_ID, scope, sealed);
+        ScriptRuntimeES6.addSymbolSpecies(cx, scope, constructor);
     }
 
     @Override
-    protected NativeUint8Array construct(NativeArrayBuffer ab, int off, int len)
-    {
+    protected NativeUint8Array construct(NativeArrayBuffer ab, int off, int len) {
         return new NativeUint8Array(ab, off, len);
     }
 
     @Override
-    public int getBytesPerElement()
-    {
+    public int getBytesPerElement() {
         return 1;
     }
 
     @Override
-    protected NativeUint8Array realThis(Scriptable thisObj, IdFunctionObject f)
-    {
+    protected NativeUint8Array realThis(Scriptable thisObj, IdFunctionObject f) {
         return ensureType(thisObj, NativeUint8Array.class, f);
     }
 
     @Override
-    protected Object js_get(int index)
-    {
+    protected Object js_get(int index) {
         if (checkIndex(index)) {
             return Undefined.instance;
         }
@@ -77,8 +66,7 @@ public class NativeUint8Array
     }
 
     @Override
-    protected Object js_set(int index, Object c)
-    {
+    protected Object js_set(int index, Object c) {
         if (checkIndex(index)) {
             return Undefined.instance;
         }
@@ -88,20 +76,18 @@ public class NativeUint8Array
     }
 
     @Override
-    public Integer get(int i)
-    {
+    public Integer get(int i) {
         if (checkIndex(i)) {
             throw new IndexOutOfBoundsException();
         }
-        return (Integer)js_get(i);
+        return (Integer) js_get(i);
     }
 
     @Override
-    public Integer set(int i, Integer aByte)
-    {
+    public Integer set(int i, Integer aByte) {
         if (checkIndex(i)) {
             throw new IndexOutOfBoundsException();
         }
-        return (Integer)js_set(i, aByte);
+        return (Integer) js_set(i, aByte);
     }
 }
