@@ -9,7 +9,6 @@ import static org.junit.Assert.assertTrue;
 import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
-
 import org.junit.BeforeClass;
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.ContextFactory;
@@ -22,15 +21,16 @@ public abstract class JsTestsBase {
 
     @BeforeClass
     public static void init() {
-        threadSafeFactory = new ContextFactory() {
-            @Override
-            protected boolean hasFeature(Context cx, int featureIndex) {
-                if (featureIndex == Context.FEATURE_THREAD_SAFE_OBJECTS) {
-                    return true;
-                }
-                return super.hasFeature(cx, featureIndex);
-            }
-        };
+        threadSafeFactory =
+                new ContextFactory() {
+                    @Override
+                    protected boolean hasFeature(Context cx, int featureIndex) {
+                        if (featureIndex == Context.FEATURE_THREAD_SAFE_OBJECTS) {
+                            return true;
+                        }
+                        return super.hasFeature(cx, featureIndex);
+                    }
+                };
     }
 
     public void setOptimizationLevel(int level) {
@@ -54,20 +54,17 @@ public abstract class JsTestsBase {
     }
 
     public void runJsTests(File[] tests) throws IOException {
-        Context cx = threadSafeFactory.enterContext();
-        try {
+        try (Context cx = threadSafeFactory.enterContext()) {
             cx.setOptimizationLevel(this.optimizationLevel);
             Scriptable shared = cx.initStandardObjects();
             for (File f : tests) {
                 int length = (int) f.length(); // don't worry about very long
-                                               // files
+                // files
                 char[] buf = new char[length];
                 new FileReader(f).read(buf, 0, length);
                 String session = new String(buf);
                 runJsTest(cx, shared, f.getName(), session);
             }
-        } finally {
-            Context.exit();
         }
     }
 }
