@@ -4,6 +4,4 @@ import org.mozilla.javascript.drivers.RhinoTest;
 import org.mozilla.javascript.drivers.ScriptTestsBase;
 
 @RhinoTest("testsrc/jstests/addition.js")
-public class AdditionTest extends ScriptTestsBase
-{
-}
+public class AdditionTest extends ScriptTestsBase {}
