@@ -10,26 +10,25 @@ import org.junit.Test;
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.ContextFactory;
 
-/**
- *
- * @author André Bargull
- */
+/** @author André Bargull */
 public class Bug637811Test {
+
     private Context cx;
 
     @Before
     public void setUp() throws Exception {
-        cx = new ContextFactory() {
-            @Override
-            protected boolean hasFeature(Context cx, int featureIndex) {
-                switch (featureIndex) {
-                case Context.FEATURE_STRICT_MODE:
-                case Context.FEATURE_WARNING_AS_ERROR:
-                    return true;
-                }
-                return super.hasFeature(cx, featureIndex);
-            }
-        }.enterContext();
+        cx =
+                new ContextFactory() {
+                    @Override
+                    protected boolean hasFeature(Context cx, int featureIndex) {
+                        switch (featureIndex) {
+                            case Context.FEATURE_STRICT_MODE:
+                            case Context.FEATURE_WARNING_AS_ERROR:
+                                return true;
+                        }
+                        return super.hasFeature(cx, featureIndex);
+                    }
+                }.enterContext();
     }
 
     @After
