@@ -2,29 +2,28 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-/**
- *
- */
+/** */
 package org.mozilla.javascript.tests;
 
-import org.mozilla.javascript.Scriptable;
+import static org.junit.Assert.assertEquals;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+import org.mozilla.javascript.Scriptable;
 
 /**
  * Tests for global functions parseFloat and parseInt.
+ *
  * @author Marc Guillemot
  */
-public class GlobalParseXTest extends TestCase {
+public class GlobalParseXTest {
 
     /**
-     * Test for bug #501972
-     * https://bugzilla.mozilla.org/show_bug.cgi?id=501972
-     * Leading whitespaces should be ignored with following white space chars
-     * (see ECMA spec 15.1.2.3)
-     * <TAB>, <SP>, <NBSP>, <FF>, <VT>, <CR>, <LF>, <LS>, <PS>, <USP>
+     * Test for bug #501972 https://bugzilla.mozilla.org/show_bug.cgi?id=501972 Leading whitespaces
+     * should be ignored with following white space chars (see ECMA spec 15.1.2.3) <TAB>, <SP>,
+     * <NBSP>, <FF>, <VT>, <CR>, <LF>, <LS>, <PS>, <USP>
      */
-    public void testParseFloatAndIntWhiteSpaces() {
+    @Test
+    public void parseFloatAndIntWhiteSpaces() {
         testParseFloatWhiteSpaces("\\u00A0 "); // <NBSP>
 
         testParseFloatWhiteSpaces("\\t ");
@@ -43,12 +42,11 @@ public class GlobalParseXTest extends TestCase {
     }
 
     /**
-     * Test for bug #531436
-     * https://bugzilla.mozilla.org/show_bug.cgi?id=531436
-     * Trailing noise should be ignored
-     * (see ECMA spec 15.1.2.3)
+     * Test for bug #531436 https://bugzilla.mozilla.org/show_bug.cgi?id=531436 Trailing noise
+     * should be ignored (see ECMA spec 15.1.2.3)
      */
-    public void testParseFloatTrailingNoise() {
+    @Test
+    public void parseFloatTrailingNoise() {
         testParseFloat("7890", "789e1");
         testParseFloat("7890", "789E1");
         testParseFloat("7890", "789E+1");
@@ -71,17 +69,17 @@ public class GlobalParseXTest extends TestCase {
         testParseFloat("789", "789e-e++hello");
     }
 
-    private void testParseFloat(final String expected, final String value) {
+    private static void testParseFloat(final String expected, final String value) {
         assertEvaluates(expected, "String(parseFloat('" + value + "'))");
     }
 
-    private void assertEvaluates(final Object expected, final String source) {
-        Utils.runWithAllOptimizationLevels(cx -> {
-            final Scriptable scope = cx.initStandardObjects();
-            final Object rep = cx.evaluateString(scope, source, "test.js",
-                    0, null);
-            assertEquals(expected, rep);
-            return null;
-        });
+    private static void assertEvaluates(final Object expected, final String source) {
+        Utils.runWithAllOptimizationLevels(
+                cx -> {
+                    final Scriptable scope = cx.initStandardObjects();
+                    final Object rep = cx.evaluateString(scope, source, "test.js", 0, null);
+                    assertEquals(expected, rep);
+                    return null;
+                });
     }
- }
+}
