@@ -2,28 +2,29 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-/**
- *
- */
+/** */
 package org.mozilla.javascript.tests;
 
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Test;
 import org.mozilla.javascript.Callable;
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.ContextFactory;
 import org.mozilla.javascript.Scriptable;
 import org.mozilla.javascript.drivers.TestUtils;
 
-import junit.framework.TestCase;
-
-/**
- * @author Norris Boyd
- */
-public class ObserveInstructionCountTest extends TestCase {
+/** @author Norris Boyd */
+public class ObserveInstructionCountTest {
     // Custom Context to store execution time.
     static class MyContext extends Context {
         MyContext(ContextFactory factory) {
             super(factory);
         }
+
         int quota;
     }
 
@@ -31,21 +32,20 @@ public class ObserveInstructionCountTest extends TestCase {
         private static final long serialVersionUID = -8018441873635071899L;
     }
 
-    @Override
-    protected void setUp() {
+    @Before
+    public void setUp() {
         TestUtils.setGlobalContextFactory(new MyFactory());
     }
 
-    @Override
-    protected void tearDown() {
+    @After
+    public void tearDown() {
         TestUtils.setGlobalContextFactory(null);
     }
 
     static class MyFactory extends ContextFactory {
 
         @Override
-        protected Context makeContext()
-        {
+        protected Context makeContext() {
             MyContext cx = new MyContext(this);
             // Make Rhino runtime call observeInstructionCount
             // each 500 bytecode instructions (if we're really enforcing
@@ -55,9 +55,8 @@ public class ObserveInstructionCountTest extends TestCase {
         }
 
         @Override
-        protected void observeInstructionCount(Context cx, int instructionCount)
-        {
-            MyContext mcx = (MyContext)cx;
+        protected void observeInstructionCount(Context cx, int instructionCount) {
+            MyContext mcx = (MyContext) cx;
             mcx.quota -= instructionCount;
             if (mcx.quota <= 0) {
                 throw new QuotaExceeded();
@@ -65,58 +64,65 @@ public class ObserveInstructionCountTest extends TestCase {
         }
 
         @Override
-        protected Object doTopCall(Callable callable,
-                                   Context cx, Scriptable scope,
-                                   Scriptable thisObj, Object[] args)
-        {
-            MyContext mcx = (MyContext)cx;
+        protected Object doTopCall(
+                Callable callable,
+                Context cx,
+                Scriptable scope,
+                Scriptable thisObj,
+                Object[] args) {
+            MyContext mcx = (MyContext) cx;
             mcx.quota = 2000;
             return super.doTopCall(callable, cx, scope, thisObj, args);
         }
     }
 
-    private void baseCase(int optimizationLevel, String source) {
-        ContextFactory factory = new MyFactory();
-        Context cx = factory.enterContext();
-        cx.setOptimizationLevel(optimizationLevel);
-        assertTrue(cx instanceof MyContext);
-        try {
-            Scriptable globalScope = cx.initStandardObjects();
-            cx.evaluateString(globalScope,
-                    source,
-                    "test source", 1, null);
-            fail();
-        } catch (QuotaExceeded e) {
-            // expected
-        } catch (RuntimeException e) {
-            fail(e.toString());
-        } finally {
-            Context.exit();
-        }
+    private static void baseCase(String source) {
+        Utils.runWithAllOptimizationLevels(
+                new MyFactory(),
+                cx -> {
+                    assertTrue(cx instanceof MyContext);
+                    try {
+                        Scriptable globalScope = cx.initStandardObjects();
+                        cx.evaluateString(globalScope, source, "test source", 1, null);
+                        fail();
+                    } catch (QuotaExceeded e) {
+                        // expected
+                    } catch (RuntimeException e) {
+                        fail(e.toString());
+                    }
+
+                    return null;
+                });
     }
 
-    public void testWhileTrueInGlobal() {
+    @Test
+    public void whileTrueInGlobal() {
         String source = "var i=0; while (true) i++;";
-        baseCase(-1, source); // interpreted mode
-        baseCase(1, source); // compiled mode
+        baseCase(source);
     }
 
-    public void testWhileTrueNoCounterInGlobal() {
+    @Test
+    public void twhileTrueNoCounterInGlobal() {
         String source = "while (true);";
-        baseCase(-1, source); // interpreted mode
-        baseCase(1, source); // compiled mode
+        baseCase(source);
     }
 
-    public void testWhileTrueInFunction() {
+    @Test
+    public void whileTrueInFunction() {
         String source = "var i=0; function f() { while (true) i++; } f();";
-        baseCase(-1, source); // interpreted mode
-        baseCase(1, source); // compiled mode
+        baseCase(source);
     }
 
-    public void testForever() {
+    @Test
+    public void forever() {
         String source = "for(;;);";
-        baseCase(-1, source); // interpreted mode
-        baseCase(1, source); // compiled mode
+        baseCase(source);
     }
 
- }
+    @Test
+    public void longRunningRegExp() {
+        String source =
+                "/(.*){1,32000}[bc]/.test(\"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa\");";
+        baseCase(source);
+    }
+}
