@@ -1,5 +1,9 @@
 package org.mozilla.javascript.tests;
 
+import java.io.BufferedReader;
+import java.io.FileReader;
+import java.io.IOException;
+import java.util.stream.Collectors;
 import org.junit.Assert;
 import org.junit.Test;
 import org.mozilla.javascript.CompilerEnvirons;
@@ -8,11 +12,6 @@ import org.mozilla.javascript.Parser;
 import org.mozilla.javascript.ast.AstRoot;
 import org.mozilla.javascript.ast.ScriptNode;
 
-import java.io.BufferedReader;
-import java.io.FileReader;
-import java.io.IOException;
-import java.util.stream.Collectors;
-
 public class ReadCommentsTest {
 
     @Test
@@ -25,7 +24,8 @@ public class ReadCommentsTest {
 
         Parser p = new Parser(compilerEnv);
         String testJs;
-        try (BufferedReader scriptIn = new BufferedReader(new FileReader("testsrc/jstests/withcomments.js"))) {
+        try (BufferedReader scriptIn =
+                new BufferedReader(new FileReader("testsrc/jstests/withcomments.js"))) {
             testJs = scriptIn.lines().collect(Collectors.joining(System.lineSeparator()));
         }
         AstRoot ast = p.parse(testJs, "test", 1);
@@ -33,6 +33,7 @@ public class ReadCommentsTest {
         ScriptNode tree = irf.transformTree(ast);
 
         Assert.assertEquals(1, tree.getFunctions().size());
-        Assert.assertEquals("/** @responseClass HttpAdapter */", tree.getFunctionNode(0).getJsDoc());
+        Assert.assertEquals(
+                "/** @responseClass HttpAdapter */", tree.getFunctionNode(0).getJsDoc());
     }
 }
