@@ -6,6 +6,7 @@
  * Tests for the Object.getOwnPropertyNames(obj) method
  */
 package org.mozilla.javascript.tests.es5;
+
 import static org.junit.Assert.assertEquals;
 import static org.mozilla.javascript.tests.Evaluator.eval;
 
@@ -16,19 +17,18 @@ import org.mozilla.javascript.ScriptableObject;
 
 public class ObjectGetOwnPropertyNamesTest {
 
-  @Test
-  public void testShouldReturnAllPropertiesOfArg() {
-    NativeObject object = new NativeObject();
-    object.defineProperty("a", "1", ScriptableObject.EMPTY);
-    object.defineProperty("b", "2", ScriptableObject.DONTENUM);
+    @Test
+    public void shouldReturnAllPropertiesOfArg() {
+        NativeObject object = new NativeObject();
+        object.defineProperty("a", "1", ScriptableObject.EMPTY);
+        object.defineProperty("b", "2", ScriptableObject.DONTENUM);
 
-    Object result = eval("Object.getOwnPropertyNames(obj)", "obj", object);
+        Object result = eval("Object.getOwnPropertyNames(obj)", "obj", object);
 
-    NativeArray names = (NativeArray) result;
-
-    assertEquals(2, names.getLength());
-    assertEquals("a", names.get(0, names));
-    assertEquals("b", names.get(1, names));
-  }
+        NativeArray names = (NativeArray) result;
 
+        assertEquals(2, names.getLength());
+        assertEquals("a", names.get(0, names));
+        assertEquals("b", names.get(1, names));
+    }
 }
