@@ -11,6 +11,4 @@ import org.mozilla.javascript.drivers.ScriptTestsBase;
 
 @RhinoTest("testsrc/jstests/es6/bad-iterators.js")
 @LanguageVersion(Context.VERSION_ES6)
-public class BadIteratorsTest extends ScriptTestsBase
-{
-}
+public class BadIteratorsTest extends ScriptTestsBase {}
