@@ -11,19 +11,14 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-
 import org.junit.Test;
 import org.mozilla.javascript.NativeWeakSet;
 
-public class NativeWeakSet2Test
-{
+public class NativeWeakSet2Test {
 
-    /**
-     * Test serialization of an empty object.
-     */
+    /** Test serialization of an empty object. */
     @Test
-    public void testSerialization()
-        throws IOException, ClassNotFoundException {
+    public void serialization() throws IOException, ClassNotFoundException {
 
         NativeWeakSet weakSet = new NativeWeakSet();
 
@@ -33,7 +28,7 @@ public class NativeWeakSet2Test
 
             try (ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
                     ObjectInputStream oin = new ObjectInputStream(bis)) {
-                NativeWeakSet result = (NativeWeakSet)oin.readObject();
+                NativeWeakSet result = (NativeWeakSet) oin.readObject();
                 assertEquals(0, result.getIds().length);
             }
         }
