@@ -4,10 +4,11 @@
 
 package org.mozilla.javascript.tests.harmony;
 
+import org.mozilla.javascript.Context;
+import org.mozilla.javascript.drivers.LanguageVersion;
 import org.mozilla.javascript.drivers.RhinoTest;
 import org.mozilla.javascript.drivers.ScriptTestsBase;
 
 @RhinoTest("testsrc/jstests/harmony/array-find.js")
-public class ArrayFindTest extends ScriptTestsBase
-{
-}
+@LanguageVersion(Context.VERSION_ES6)
+public class ArrayFindTest extends ScriptTestsBase {}
