@@ -8,6 +8,4 @@ import org.mozilla.javascript.drivers.RhinoTest;
 import org.mozilla.javascript.drivers.ScriptTestsBase;
 
 @RhinoTest("testsrc/jstests/harmony/typed-array-slice.js")
-public class TypedArraySliceTest extends ScriptTestsBase
-{
-}
+public class TypedArraySliceTest extends ScriptTestsBase {}
