@@ -27,17 +27,18 @@ public class XmlNonResettableDocumentBuilderTest {
     }
 
     @Test
-    public void testNonResettableDocumentBuilder() {
-        Context cx = new ContextFactory().enterContext();
-        try {
+    public void nonResettableDocumentBuilder() {
+        try (Context cx = new ContextFactory().enterContext()) {
             Scriptable scope = cx.initStandardObjects();
-            Object result = cx.evaluateString(scope,
-                    "var employees = new XML('<employees><employee><name>John</name></employee></employees>');" +
-                    "employees.employee.name;",
-                    "source", 1, null);
+            Object result =
+                    cx.evaluateString(
+                            scope,
+                            "var employees = new XML('<employees><employee><name>John</name></employee></employees>');"
+                                    + "employees.employee.name;",
+                            "source",
+                            1,
+                            null);
             Assert.assertEquals("John", String.valueOf(result));
-        } finally {
-            Context.exit();
         }
     }
 }
