@@ -1,12 +1,12 @@
-/* -*- Mode: java; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+/* -*- Mode: javascript; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '9.1.1.10.js';
+gTestfile = '9.2.1.10.js';
 
-START("9.1.1.10 - XML [[ResolveValue]]");
+START("9.2.1.10 XMLList [[ResolveValue]]");
 
 var actual = 'Test not implemented';
 var expect = 'PASS';
@@ -14,3 +14,4 @@ var expect = 'PASS';
 TEST(1, expect, actual);
 
 END();
+
