@@ -1,31 +1,31 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '15.9.5.13-6.js';
+gTestfile = '15.9.5.11-4.js';
 
 /**
-   File Name:          15.9.5.13.js
-   ECMA Section:       15.9.5.13
-   Description:        Date.prototype.getUTCDay
+   File Name:          15.9.5.11.js
+   ECMA Section:       15.9.5.11
+   Description:        Date.prototype.getUTCDate
 
    1.Let t be this time value.
    2.If t is NaN, return NaN.
-   3.Return WeekDay(t).
+   1.Return DateFromTime(t).
 
    Author:             christine@netscape.com
    Date:               12 november 1997
 */
 
-var SECTION = "15.9.5.13";
+var SECTION = "15.9.5.11";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Date.prototype.getUTCDay()";
+var TITLE   = "Date.prototype.getUTCDate()";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-addTestCase( UTC_FEB_29_2000 );
+addTestCase( TIME_1900 );
 
 test();
 
@@ -36,9 +36,8 @@ function addTestCase( t ) {
   for (var d = start; d < stop; d += msPerDay)
   {
     new TestCase( SECTION,
-                  "(new Date("+d+")).getUTCDay()",
-                  WeekDay((d)),
-                  (new Date(d)).getUTCDay() );
+                  "(new Date("+d+")).getUTCDate()",
+                  DateFromTime(d),
+                  (new Date(d)).getUTCDate() );
   }
 }
-
