@@ -1,12 +1,12 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '7.4.2-2-n.js';
+gTestfile = '7.4.2-12-n.js';
 
 /**
-   File Name:          7.4.2-2-n.js
+   File Name:          7.4.2-12-n.js
    ECMA Section:       7.4.2
 
    Description:
@@ -29,16 +29,16 @@ gTestfile = '7.4.2-2-n.js';
    Date:               12 november 1997
 
 */
-var SECTION = "7.4.1-2-n";
+var SECTION = "7.4.1-12-n";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Keywords";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-DESCRIPTION = "var for = true";
+DESCRIPTION = "var while = true";
 EXPECTED = "error";
 
-new TestCase( SECTION,  "var for = true",     "error",    eval("var for = true") );
+new TestCase( SECTION,  "var while = true",     "error",    eval("var while = true") );
 
 test();
