@@ -1,12 +1,12 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-gTestfile = '15.2.3.1-1.js';
+gTestfile = '15.2.3.1-4.js';
 
 /**
-   File Name:          15.2.3.1-1.js
+   File Name:          15.2.3.1-4.js
    ECMA Section:       15.2.3.1 Object.prototype
 
    Description:        The initial value of Object.prototype is the built-in
@@ -15,13 +15,14 @@ gTestfile = '15.2.3.1-1.js';
    This property shall have the attributes [ DontEnum,
    DontDelete ReadOnly ]
 
-   This tests the [DontEnum] property of Object.prototype
+   This tests the [DontDelete] property of Object.prototype
 
    Author:             christine@netscape.com
    Date:               28 october 1997
 
 */
-var SECTION = "15.2.3.1-1";
+
+var SECTION = "15.2.3.1-4";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Object.prototype";
@@ -29,8 +30,8 @@ var TITLE   = "Object.prototype";
 writeHeaderToLog( SECTION + " "+ TITLE);
 
 new TestCase( SECTION, 
-	      "var str = '';for ( p in Object ) { str += p; }; str",
-	      "",
-	      eval( "var str = ''; for ( p in Object ) { str += p; }; str" ) );
+	      "delete( Object.prototype ); Object.prototype",
+	      Object.prototype,
+	      eval("delete(Object.prototype); Object.prototype") );
 
 test();
