@@ -1,12 +1,12 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = '11.7.2-01.js';
+var gTestfile = '11.10-01.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 396969;
-var summary = '11.7.2 - >> should evaluate operands in order';
+var summary = '11.10 - & should evaluate operands in order';
 var actual = '';
 var expect = '';
 
@@ -23,7 +23,7 @@ function test()
 
   expect = 'o.valueOf, p.valueOf';
   var actualval;
-  var expectval = 10;
+  var expectval = 2;
 
   var o = {
     valueOf: (function (){ actual += 'o.valueOf'; return this.value}), 
@@ -35,7 +35,7 @@ function test()
     value:2
   };
 
-  actualval = (o >> p);
+  actualval = (o & p);
 
   reportCompare(expectval, actualval, summary + ': value');
   reportCompare(expect, actual, summary + ': order');
