@@ -1,12 +1,13 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = '15.7.4.7-2.js';
+var gTestfile = '15.7.4.3-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = "411893";
-var summary = "num.toPrecision(undefined) should equal num.toString()";
+var BUGNUMBER = "412068";
+var summary = "num.toLocaleString incorrectly accesses its first argument " +
+              "even when no first argument has been given";
 var actual, expect;
 
 printBugNumber(BUGNUMBER);
@@ -20,14 +21,10 @@ var failed = false;
 
 try
 {
-  var prec = 3.3.toPrecision(undefined);
-  var str  = 3.3.toString();
-  if (prec !== str)
-  {
-    throw "not equal!  " +
-          "3.3.toPrecision(undefined) === '" + prec + "', " +
-          "3.3.toString() === '" + str + "'";
-  }
+  if ("3" !== 3..toLocaleString())
+    throw '"3" should equal 3..toLocaleString()';
+  if ("9" !== 9..toLocaleString(8))
+    throw 'Number.prototype.toLocaleString should ignore its first argument';
 }
 catch (e)
 {
