@@ -1,15 +1,14 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-441477-01.js';
+var gTestfile = 'regress-385393-04.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 441477-01;
-var summary = '';
-var actual = 'No Exception';
-var expect = 'No Exception';
-
+var BUGNUMBER = 385393;
+var summary = 'Regression test for bug 385393';
+var actual = 'No Crash';
+var expect = 'No Crash';
 
 //-----------------------------------------------------------------------------
 test();
@@ -23,18 +22,12 @@ function test()
  
   try
   {
-    for (i = 0; i < 5;) 
-    { 
-      if (i > 5) 
-        throw "bad"; 
-      i++; 
-      continue; 
-    }
+    'a'.replace(/a/g, eval);
   }
   catch(ex)
   {
-    actual = ex + '';
   }
+
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
