@@ -1,14 +1,15 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-452724-02.js';
+var gTestfile = 'regress-470758-02.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 452724;
-var summary = 'Do not crash with JIT: @TraceRecorder::getThis';
-var actual = 'No Crash';
-var expect = 'No Crash';
+var BUGNUMBER = 470758;
+var summary = 'Promote evald initializer into upvar';
+var actual = '';
+var expect = '';
+
 
 //-----------------------------------------------------------------------------
 test();
@@ -19,12 +20,10 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
+ 
+  expect = 5;
 
-  jit(true);
-
-  for (var j=0;j<5;++j) { (0/0) in this; }
-
-  jit(false);
+  (function(){var x;eval("for (x = 0; x < 5; x++);");print(actual = x);})();
 
   reportCompare(expect, actual, summary);
 
