@@ -1,9 +1,9 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-56940-02.js';
+var gTestfile = 'regress-56940-01.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 56940;
 var summary = 'String concat should not be O(N**2)';
@@ -41,7 +41,7 @@ function concat(size)
 
   for (var loop = 0; loop < size; loop++)
   {
-    x += y + z + y + z + y + z;
+    x = x + y + z + y + z + y + z;
   }
   var stop = new Date();
   return stop - start;
