@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -23,7 +23,7 @@ function test()
  
   var f, g;
   f = function() { { while(0) function t() {  } } }
-  expect = 'function() { while(false) { function t() {  } }}';
+  expect = 'function() { while(0) { function t() {  } }}';
   actual = f + '';
   compareSource(expect, actual, summary);
 
