@@ -1,9 +1,10 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
 var gTestfile = 'regress-396326.js';
+
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 396326;
 var summary = 'Do not assert trying to disassemble get(var|arg) prop';
@@ -28,10 +29,20 @@ function test()
   }
   else
   {
-    function f4() { let local; return local.prop }; 
-    dis(f4);
+    function f1() { var v; return v.prop }; 
+    dis(f1);
     reportCompare(expect, actual, summary + 
-                  ': function f4() { let local; return local.prop };');
+                  ': function f1() { var v; return v.prop };');
+
+    function f2(arg) { return arg.prop }; 
+    dis(f2);
+    reportCompare(expect, actual, summary + 
+                  ': function f2(arg) { return arg.prop };');
+
+    function f3() { return this.prop }; 
+    dis(f3);
+    reportCompare(expect, actual, summary + 
+                  ': function f3() { return this.prop };');
   }
 
   exitFunc ('test');
