@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -6,7 +6,7 @@
 var gTestfile = 'regress-474771.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 474771;
-var summary = 'gczeal, prototype mangling, for..in';
+var summary = 'TM: do not halt execution with gczeal, prototype mangling, for..in';
 var actual = '';
 var expect = '';
 
@@ -22,12 +22,18 @@ function test()
   printStatus (summary);
 
   expect = 'PASS';
-  if (typeof gczeal == 'function')
+  jit(true);
+
+  if (typeof gczeal != 'undefined')
   {
     gczeal(2);
   }
   Object.prototype.q = 3;
   for each (let x in [6, 7]) { } print(actual = "PASS");
+ 
+  jit(false);
+
+  delete Object.prototype.q;
 
   reportCompare(expect, actual, summary);
 
