@@ -1,12 +1,12 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-var gTestfile = 'regress-373678-01.js';
+var gTestfile = 'regress-469625-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 373678;
-var summary = 'Missing quotes around string in decompilation, with for..in and do..while ';
+var BUGNUMBER = 469625;
+var summary = 'decompile [a, b, [c0, c1]] = [x, x, x];';
 var actual = '';
 var expect = '';
 
@@ -21,9 +21,13 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
-  var f = function() { do {for(a.b in []) { } } while("c\\d"); };
-  expect = 'function() { do {for(a.b in []) { } } while(true); }';
+  function f(x) {
+    var [a, b, [c0, c1]] = [x, x, x];
+  }
+
+  expect = 'function f(x) { var [a, b, [c0, c1]] = [x, x, x]; }';
   actual = f + '';
+
   compareSource(expect, actual, summary);
 
   exitFunc ('test');
