@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
+/* -*- Mode: javascript; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -6,7 +6,7 @@
 var gTestfile = 'regress-469625.js';
 //-----------------------------------------------------------------------------
 var BUGNUMBER = 469625;
-var summary = 'TM: Do not crash @ js_String_getelem';
+var summary = 'TM: Array prototype and expression closures';
 var actual = '';
 var expect = '';
 
@@ -21,11 +21,20 @@ function test()
   printBugNumber(BUGNUMBER);
   printStatus (summary);
  
+  expect = 'TypeError: [] is not a function';
+
   jit(true);
 
-  [].__proto__[0] = 'a';
-  for (var j = 0; j < 3; ++j) [[, ]] = [];
+  Array.prototype.__proto__ = function () 3; 
 
+  try
+  {
+    [].__proto__();
+  }
+  catch(ex)
+  {
+    print(actual = ex + '');
+  }
   jit(false);
 
   reportCompare(expect, actual, summary);
